@@ -1,4 +1,4 @@
-/* $Revision: 262 $ */
+/* $Revision: 275 $ */
 #define _GNU_SOURCE
 #include <stdio.h>
 #include <libintl.h>
@@ -631,6 +631,9 @@ void draw_graph(double val)
 		n++;
 	}
 
+	if (!n)
+		return;
+
 	avg /= (double)n;
 	sd = sqrt((sd / (double)n) - pow(avg, 2.0));
 
